@@ -1,5 +1,5 @@
 package Curio::Factory;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =encoding utf8
 
@@ -832,7 +832,8 @@ sub inject {
     );
 
 This is just like L</inject> except it returns an guard object which,
-when it leaves scope and is destroyed, will automatically L</uninject>.
+when it leaves scope and is destroyed, will automatically
+L</clear_injection>.
 
 =cut
 
@@ -843,31 +844,29 @@ sub inject_with_guard {
     my $key = (@_==1) ? undef : shift( @_ );
 
     return Curio::Guard->new(sub{
-        $class->factory->uninject( $key ? $key : () );
+        $class->factory->clear_injection( $key ? $key : () );
     });
 }
 
-=head2 uninject
+=head2 clear_injection
 
-    my $curio_object = $factory->uninject();
-    my $curio_object = $factory->uninject( $key );
+    my $curio_object = $factory->clear_injection();
+    my $curio_object = $factory->clear_injection( $key );
 
-Removes the previously injected curio object, restoring the
-original behavior of L</fetch_curio>.
+Removes the previously injected curio object, restoring the original
+behavior of L</fetch_curio>.
 
-Returns the previously injected curio object.
+Returns the previously injected curio object, or C<undef> if there was
+not one.
 
 =cut
 
-sub uninject {
+sub clear_injection {
     my $self = shift;
     my $key = $self->_process_key_arg( \@_ );
 
     $key = $undef_key if !defined $key;
 
-    croak 'Cannot uninject a Curio object where one has not already been injected'
-        if !$self->_get_injection( $key );
-
     my $curio = $self->_remove_injection( $key );
 
     return $curio;
@@ -878,7 +877,8 @@ sub uninject {
     my $curio_object = $factory->injection();
     my $curio_object = $factory->injection( $key );
 
-Returns the injected curio object, or C<undef> if none has been injected.
+Returns the injected curio object, or C<undef> if none has been
+injected.
 
 =cut
 
@@ -891,6 +891,24 @@ sub injection {
     return $self->_get_injection( $key );
 }
 
+=head2 has_injection
+
+    if ($factory->has_injection()) { ... }
+    if ($factory->has_injection( $key )) { ... }
+
+Returns true (C<1>) if an injection is in place.
+
+=cut
+
+sub has_injection {
+    my $self = shift;
+    my $key = $self->_process_key_arg( \@_ );
+
+    $key = $undef_key if !defined $key;
+
+    return $self->_get_injection( $key ) ? 1 : 0;
+}
+
 1;
 __END__
 
